@@ -243,12 +243,28 @@ GSwitchItAppletFilterXEvt (GdkXEvent * xev, GdkEvent * event)
 
 	XklFilterEvents (xevent);
 	switch (xevent->type) {
+	case DestroyNotify:
+		{
+			XDestroyWindowEvent *de = (XDestroyWindowEvent *) xev;
+			
+			ForAllApplets ()
+				GdkWindow * w = sia->appletAncestor;
+
+				/* compare the applet's parent window with the even window */
+				if (w != NULL && GDK_WINDOW_XID (w) == de->window) {
+					sia->appletAncestor = NULL;
+				}
+			NextApplet
+
+		}
+		break;
 	case ReparentNotify:
 		{
 			XReparentEvent *rne = (XReparentEvent *) xev;
 
 			ForAllApplets ()
 				GdkWindow * w = sia->appletAncestor;
+
 				/* compare the applet's parent window with the even window */
 				if (w != NULL && GDK_WINDOW_XID (w) == rne->window) {
 					/* if so - make it transparent...*/
@@ -584,6 +600,10 @@ GSwitchItPreviewResponse (GtkWidget *dialog, gint resp)
 {
 	switch (resp) 
 	{
+		case GTK_RESPONSE_HELP:
+			GSwitchItHelp (GTK_WIDGET (dialog),
+				       "layout-view");
+			break;
 		case GTK_RESPONSE_CLOSE:
 			gtk_widget_destroy (dialog);
 		default:;
