@@ -24,9 +24,11 @@ static const unsigned needed_cpu_flags =
 (1 << GLIBTOP_CPU_SYS) +
 (1 << GLIBTOP_CPU_NICE);
 
+#if 0
 static const unsigned needed_page_flags =
 (1 << GLIBTOP_SWAP_PAGEIN) +
 (1 << GLIBTOP_SWAP_PAGEOUT);
+#endif
 
 static const unsigned needed_mem_flags =
 (1 << GLIBTOP_MEM_USED) +
@@ -56,14 +58,11 @@ GetLoad (int Maximum, int data [5], LoadGraph *g)
 	
     g_return_if_fail ((cpu.flags & needed_cpu_flags) == needed_cpu_flags);
 
-    if (!(cpu.flags & GLIBTOP_CPU_IOWAIT))
-	cpu.iowait = 0;
-    
     g->cpu_time [0] = cpu.user;
     g->cpu_time [1] = cpu.nice;
     g->cpu_time [2] = cpu.sys;
-    g->cpu_time [3] = cpu.iowait;
-    g->cpu_time [4] = cpu.idle - cpu.iowait;
+    g->cpu_time [3] = cpu.iowait + cpu.irq + cpu.softirq;
+    g->cpu_time [4] = cpu.idle;
 
     if (!g->cpu_initialized) {
 	memcpy (g->cpu_last, g->cpu_time, sizeof (g->cpu_last));
@@ -80,13 +79,11 @@ GetLoad (int Maximum, int data [5], LoadGraph *g)
 
     memcpy(g->cpu_last, g->cpu_time, sizeof g->cpu_last);
 
-    if (!total) total = Maximum;
-
     usr  = rint (Maximum * (float)(usr)  / total);
     nice = rint (Maximum * (float)(nice) / total);
     sys  = rint (Maximum * (float)(sys)  / total);
     iowait = rint (Maximum * (float)(iowait) / total);
-    free = rint (Maximum * (float)(free) / total);
+    free = Maximum - usr - nice - sys - iowait;
 
     data [0] = usr;
     data [1] = sys;
@@ -123,6 +120,11 @@ GetDiskLoad (int Maximum, int data [3], LoadGraph *g)
 	for (i = 0; i < mountlist.number; i++)
 	{
 		glibtop_fsusage fsusage;
+
+		if (strcmp(mountentries[i].type, "smbfs") == 0
+		    || strcmp(mountentries[i].type, "nfs") == 0)
+			continue;
+
 		glibtop_get_fsusage(&fsusage, mountentries[i].mountdir);
 		read += fsusage.read; write += fsusage.write;
 	}
@@ -240,7 +242,7 @@ GetSwap (int Maximum, int data [2], LoadGraph *g)
     }
 
     data [0] = used;
-    data [1] = free;
+    data [1] = Maximum - used;
 }
 
 void
@@ -262,7 +264,7 @@ GetLoadAvg (int Maximum, int data [2], LoadGraph *g)
     free    = (max_loadavg - loadavg1) / max_loadavg;
 
     data [0] = rint ((float) Maximum * used);
-    data [1] = rint ((float) Maximum * free);
+    data [1] = Maximum - data[0];
 }
 
 
